@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 #
-# $Id: lexer.rb 66189 2018-12-04 08:22:10Z kazu $
+# $Id: lexer.rb 67208 2019-03-11 06:52:01Z naruse $
 #
 # Copyright (c) 2004,2005 Minero Aoki
 #
@@ -83,6 +83,12 @@ class Ripper
 
     private
 
+    unless SCANNER_EVENT_TABLE.key?(:ignored_sp)
+      SCANNER_EVENT_TABLE[:ignored_sp] = 1
+      SCANNER_EVENTS << :ignored_sp
+      EVENTS << :ignored_sp
+    end
+
     def on_heredoc_dedent(v, w)
       ignored_sp = []
       heredoc = @buf.last
